"use strict";

exports.__esModule = true;
exports.default = setNativeProps;

var _universalEnv = require("universal-env");

var _styleUnit = require("style-unit");

var _rax = require("rax");

var _flexbox = _interopRequireDefault(require("./flexbox"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ADD_EVENT = 'addEvent';
var DANGEROUSLY_SET_INNER_HTML = 'dangerouslySetInnerHTML';
var CLASS_NAME = 'className';
var CLASS = 'class';
var STYLE = 'style';
var CHILDREN = 'children';
var EVENT_PREFIX_REGEXP = /^on[A-Z]/;
var objectPrototypeHasOwnProperty = Object.prototype.hasOwnProperty;

function hasOwnProperty(obj, key) {
  return objectPrototypeHasOwnProperty.call(obj, key);
}

function setStyles(node, styles) {
  if (_universalEnv.isWeb) {
    var tranformedStyles = {};

    for (var prop in styles) {
      var val = styles[prop];

      if (_flexbox.default.isFlexProp(prop)) {
        _flexbox.default[prop](val, tranformedStyles);
      } else {
        tranformedStyles[prop] = (0, _styleUnit.convertUnit)(val, prop);
      }
    }

    for (var _prop in tranformedStyles) {
      var transformValue = tranformedStyles[_prop]; // hack handle compatibility issue

      if (Array.isArray(transformValue)) {
        for (var i = 0; i < transformValue.length; i++) {
          node.style[_prop] = transformValue[i];
        }
      } else {
        node.style[_prop] = transformValue;
      }
    }
  } else if (_universalEnv.isWeex) {
    _rax.shared.Host.driver.setStyle(node, styles);
  }
}

function addEventListener(node, eventName, eventHandler, props) {
  if (_universalEnv.isWeb) {
    if (this.eventRegistry[eventName]) {
      return this.eventRegistry[eventName](ADD_EVENT, node, eventName, eventHandler, props);
    } else {
      return node.addEventListener(eventName, eventHandler);
    }
  } else if (_universalEnv.isWeex) {
    _rax.shared.Host.driver.addEventListener(node, eventName, eventHandler, props);
  }
}

function setAttribute(node, propKey, propValue) {
  if (_universalEnv.isWeb) {
    if (propKey === DANGEROUSLY_SET_INNER_HTML) {
      return node.innerHTML = propValue.__html;
    }

    if (propKey === CLASS_NAME) {
      propKey = CLASS;
    }

    if (propKey in node) {
      try {
        node[propKey] = propValue;
      } catch (e) {
        node.setAttribute(propKey, propValue);
      }
    } else {
      node.setAttribute(propKey, propValue);
    }
  } else if (_universalEnv.isWeex) {
    _rax.shared.Host.driver.setAttribute(node, propKey, propValue);
  }
}
/**
 * Set props directly to native node.
 * @param {Node} node Reference to node intance.
 * @param {Obejct} props k-v structure to props.
 */


function setNativeProps(node, props) {
  if (props === void 0) {
    props = {};
  }

  for (var prop in props) {
    if (!hasOwnProperty(props, prop)) continue;
    var value = props[prop]; // Skip children.

    if (prop === CHILDREN) continue; // Skip nullable value.

    if (value === null || value === undefined) continue;

    if (prop === STYLE) {
      setStyles(node, value);
    } else if (EVENT_PREFIX_REGEXP.test(prop)) {
      var eventName = prop.slice(2).toLowerCase();
      addEventListener(node, eventName, value, props);
    } else {
      setAttribute(node, prop, value);
    }
  }
}